import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const titleText = 'Top 10 Most Populous Countries';
const xAxisLabelText = 'Population';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  
  const xValue = d => d['population']
  const yValue = d => d['country']
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, width]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, height-100])
    .padding(0.1)
  
  const numberFormat = number =>
    format('.6s')(number)
  
  const xAxis = axisBottom(xScale)
    .tickFormat(numberFormat)
  
  svg.append("g")
    .call(xAxis)
    .attr("transform", "translate(0,400)")
  
  svg.selectAll('rect')
     .data(data)
     .enter()
     .append('rect')
     .attr("x", 0)
     .attr("y", d => yScale(yValue(d)))
     .attr("width", d => xScale(xValue(d)))
     .attr("height", yScale.bandwidth);
};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population * 1000;
  });
  render(data);
});